module sys(
  // inputs:
  clk,
  reset_n,
  ir,
  
  // outputs:
  ss1,
  ss0
);
  input ir;
  input clk;
  input reset_n;
  
  output [7:0] ss1;
  output [7:0] ss0;

  wire signal_to_watch = ir;

  reg d1_signal_to_watch;
  always @(posedge clk or negedge reset_n) begin
    if (!reset_n) begin
      d1_signal_to_watch <= 1'b1;
    end
    else begin
      d1_signal_to_watch <= signal_to_watch;
    end
  end

  `define COUNTER_WIDTH 20
  // Write on each signal_to_watch transition.
  wire wreq = d1_signal_to_watch ^ signal_to_watch;

  reg [(`COUNTER_WIDTH - 1):0] counter /* synthesis preserve=1 */;
  always @(posedge clk or negedge reset_n) begin
    if (!reset_n) begin
      counter <= `COUNTER_WIDTH'b0;
    end
    else begin
      if (wreq) begin
        counter <= `COUNTER_WIDTH'b0;
      end 
      else begin
        counter <= counter + 1'b1;
      end
    end
  end

  wire [5:0] rdusedw;
  vj_rw the_vj_rw(
    .readdata (fifo_readdata),
    .rdempty (rdempty),
    .rdfull (rdfull),
    .rdusedw (rdusedw),

    .ack_readdata (rreq),
    .ack_rdempty (),
    .ack_rdusedw (),
    .ack_rdfull (),
    .vj_clk (vj_clk),
  );

  wire rreq;
  wire wrfull;
  wire rdfull;
  wire [(`COUNTER_WIDTH - 1):0] fifo_readdata /* synthesis preserve=1 */;
  fifo the_fifo (
    .q (fifo_readdata),
    .rdclk (vj_clk),
    .rdreq (rreq),
    .rdempty (rdempty),
    .rdusedw (rdusedw),

    .rdfull (rdfull),
    .data (counter),
    .wrclk (clk),
    .wrreq (wreq),
    .wrfull (wrfull)
  );

  `define BLINK_COUNTER_WIDTH 24
  `define BLINK_COUNTER_MSB `BLINK_COUNTER_WIDTH - 1
  reg [`BLINK_COUNTER_MSB:0] blink_counter;
  wire [`BLINK_COUNTER_MSB:0] p1_blink_counter = blink_counter + 1'b1;
  always @(posedge clk) begin
    blink_counter <= p1_blink_counter;
  end

  wire blink = blink_counter[`BLINK_COUNTER_MSB];

  assign {ss1, ss0} = {~8'b11111100,  ~8'b10111111} ^ blink;
endmodule

